<!--
SPDX-FileCopyrightText: 2024 Red Hat, Inc

SPDX-License-Identifier: GPL-2.0-or-later
-->

A sample schema package.

See https://fedora-messaging.readthedocs.io/en/latest/messages.html for
detailed documentation on packaging your schema.
